<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR" sourcelanguage="en">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>Saltar para o PDF</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>Sem sugestões</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>Ignorar palavra</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Impossível apagar</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Alguns dos arquivos auxiliares não puderam ser removidos. Talvez você não tenha permissão para apagá-los.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>Confirme o apagamento do arquivo</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>Arquivos auxiliares que serão apagados:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished">Selecionar Tudo</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Procurar:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Retornando ao início</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Procurar até o &amp;início</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>Procurar na &amp;seleção</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Procurar &amp;todas as ocorrências</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Procurar e &amp;abrir arquivos</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>Diferenciar &amp;maiúsculas</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Palavras inteiras</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>Expressões &amp;regulares</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nenhuma chave de busca recente</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(inválido)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Quebra de linha</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Quebrar linhas em:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Tamanho da janela atual</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Comprimento da linha:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Reformatar parágrafos</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Abrir recente</translation>
    </message>
    <message>
        <source>PDF file &quot;%1&quot; is locked; this is not currently supported.</source>
        <translation>Arquivo PDF &quot;%1&quot; está trancado; isto não é atualmente suportado.</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>Falha ao abrir o arquivo &quot;%1&quot;; talvez não seja um documento PDF válido.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>Nenhuma informação SyncTeX disponível</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>página %1 de %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation></translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>novo.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Exibir</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de Ferramentas</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Sobre TeXworks...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Primeira Página</translation>
    </message>
    <message>
        <source>Home</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Página Anterior</translation>
    </message>
    <message>
        <source>PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Próxima Página</translation>
    </message>
    <message>
        <source>PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Última Página</translation>
    </message>
    <message>
        <source>End</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Ir para a página...</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Aumentar</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Diminuir</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Ajustar à Janela</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Tamanho Real</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Ajustar à Largura</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation></translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferências...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Empilhar</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Distribuir</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>Trabalhar no código</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Novo a partir de Modelo...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Aumentar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rolar</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Selecionar Texto</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Selecionar Imagem</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Visitar a página do TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escrever para a lista de usuários</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Lado a Lado</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Colocar à esquerda</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Colocar à Direita</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Sair do TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Procurar...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Procurar Outra Vez</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nenhuma chave de busca recente</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>Procurar no PDF</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Procurar:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Retornando ao início</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Procurar até o &amp;início</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Procurar &amp;todas as ocorrências</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>Diferenciar &amp;maiúsculas</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;Sincronizar com código-fonte</translation>
    </message>
</context>
<context>
    <name>PDFFontsDock</name>
    <message>
        <source>Name</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>sim</translation>
    </message>
    <message>
        <source>no</source>
        <translation>não</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[incluído]</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fontes</translation>
    </message>
</context>
<context>
    <name>PDFInfoDock</name>
    <message>
        <source>PDF Info</source>
        <translation>Informação do PDF</translation>
    </message>
</context>
<context>
    <name>PDFOutlineDock</name>
    <message>
        <source>No TOC</source>
        <translation>Sem Sumário</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Conteúdo</translation>
    </message>
</context>
<context>
    <name>PDFWidget</name>
    <message>
        <source>Zoom In</source>
        <translation>Aumentar</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Diminuir</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Tamanho Real</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Ajustar à Largura</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Ajustar à Janela</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Saltar para o código-fonte</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Ir para a página</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Número da página:</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Escolher Pasta</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Nova Ferramenta</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Padrão do sistema [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>Preferências do TeXworks</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Toolbar buttons</source>
        <translation>Botões da barra de ferramentas</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Ícones pequenos</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Ícones médios</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Ícones grandes</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Mostrar texto com os ícones</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>Ao iniciar, exibir</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Novo documento vazio</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Caixa de seleção de modelo</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Caixa de abertura de arquivo</translation>
    </message>
    <message>
        <source>Interface locale:</source>
        <translation>Localização da interface:</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Padrões do editor</translation>
    </message>
    <message>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Largura das tabulações:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Números de linha</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>Quebrar linhas</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Realce de sintaxe:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Modo de auto-indentação:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Língua da verificação ortográfica:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Codificação:</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Opções globais do editor</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Realçar a linha atual</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Prever</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Escala padrão</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Tamanho real</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Ajustar à Largura</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Ajustar à Janela</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Escala fixa:</translation>
    </message>
    <message>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Lente de aumento</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Lente de aumento circular</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Resolução da tela:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation> ppp</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Composição</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>Localização do TeX e programas relacionados</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>Ferramentas de processamento</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Editar...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>Padrão:</translation>
    </message>
    <message>
        <source>Auto-hide output panel unless errors occur</source>
        <translation>Ocultar automaticamente o painel de mensagens se não ocorrerem erros</translation>
    </message>
    <message>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>Documentos do TeX (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>Documentos LaTeX (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>Bases de dados BibTeX (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>Arquivos de estilo (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>Arquivos de classe (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Macros documentadas (*.dtx)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</source>
        <translation>Arquivos auxliares (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Arquivos de texto (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>Arquivos PDF (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Substituir Tudo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nenhuma chave de busca recente</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>Nenhuma chave de substituição recente</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(inválido)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Substituir:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>Por:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Retornando ao início</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Procurar até o &amp;início</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>Substituir na &amp;seleção</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>Substituir em &amp;todos os arquivos</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>Diferenciar &amp;maiúsculas</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Palavras inteiras</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>Expressões &amp;regulares</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Context: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Começo</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fim</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Resultados da Busca</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Novo a partir de Modelo...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferências...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Abrir recente</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Visitar a página do TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escrever para a lista de usuários</translation>
    </message>
    <message>
        <source>About </source>
        <translation>Sobre </translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 é um ambiente simples para editar, compilar e prever documentos TeX.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (r.%2)</source>
        <translation type="obsolete">&lt;br&gt;Versão %1 (r%2)</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
        <translation>&lt;p&gt;Distribuído sob a &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;Licença Pública Geral GNU&lt;/a&gt;, versão 2.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; application framework by Qt Software, a division of Nokia Corporation.</source>
        <translation type="obsolete">&lt;p&gt;Ambiente de desenvolvimento &lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; da Qt Software, uma divisão da Nokia Corporation.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;Biblioteca de renderização de PDF &lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt;, por Kristian H&amp;#xF8;gsberg, Albert Astals-Cid e outros.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.sourceforge.net/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;Verificador ortográfico &lt;a href=&quot;http://hunspell.sourceforge.net/&quot;&gt;Hunspell&lt;/a&gt;, por L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Conceito e recursos inspirados no &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; de Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;Tecnologia &lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; por J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Alguns ícones usados são do &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;tradução %1 gentilmente contribuída por %2.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>José Geraldo Gouvêa/jggouvea@gmail.com</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>Impossível acessar &quot;%1&quot;; o navegador ou leitor de correio está configurado corretamente?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Impossível criar janela</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Algo está muito errado; %1 foi incapaz de criar uma janela de documento. O programa finalizará agora.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>Pasta padrão dos binários não encontrada</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.</source>
        <translation>Nenhuma das pastas predefinidas para os programas relacionados ao TeX pode ser encontrada.&lt;p&gt;&lt;small&gt;Para executar quaisquer processos você precisará configurar a(s) pasta(s) de binários de sua distribuição TeX usando a aba Composição da caixa de Preferências.</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>Impossível achar arquivo de ajuda.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="unfinished">Salvar o arquivo</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Esquema</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Sem etiquetas</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Novo documento</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Abrir Recente</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <source>Cannot close window while tool is running</source>
        <translation type="obsolete">Impossivel fechar janela enquanto a ferramenta está em execução</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Salvar o arquivo</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>O documento &quot;%1&quot; foi modificado.
Você quer salvar suas mudanças?</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>Você quer descartar todas as mudanças no documento &quot;%1&quot; e reverter para a última versão salva?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Reverter</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">Impossível ler arquivo &quot;%1&quot;:
%2.</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Codificação não reconhecida</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>A codificação de texto %1 usada em %2 não é suportada.

Será interpretada como %3, o que poderá resultar em texto incorreto.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded (%2)</source>
        <translation type="obsolete">Arquivo &quot;%1&quot; aberto (%2)</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>Arquivo modificado no disco</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 foi modificado por outro programa.

Você quer descartar suas mudanças atuais e reabrir o arquivo a partir do disco?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 foi modificado por outro programa.

Você quer continuar e salvar este arquivo, sobrescrevendo a versão do disco?</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>O documento &quot;%1&quot; não foi salvo</translation>
    </message>
    <message>
        <source>The text encoding %1 requested for %2 is not supported.

It will be saved as %3 instead, which may result in incorrect text.</source>
        <translation type="obsolete">A codificação de texto %1 escolhida para %2 não é suportada.

O arquivo será salvo como %3, o que poderá resultar em texto incorreto.</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>O texto não pôde ser convertido</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Este documento contém caracteres que não podem ser representados na codificação %1.

Se você continuar, eles serão substituídos por códigos-padrão. Em vez disso, você pode escolher usar outra codificação (como UTF-8) para evitar perda de informação.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">Impossível gravar arquivo &quot;%1&quot;:
%2.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved (%2)</source>
        <translation type="obsolete">Arquivo &quot;%1&quot; salvo (%2)</translation>
    </message>
    <message>
        <source>default encoding</source>
        <translation type="obsolete">codificação padrão</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>novo-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Linha %1 de %2; coluna %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Ir para a Linha</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Número da linha:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Expressão regular inválida</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Não encontrado</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>Encontrada %n ocorrência</numerusform>
            <numerusform>Encontradas %n ocorrências</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n ocorrência</numerusform>
            <numerusform>%n ocorrências</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n documento</numerusform>
            <numerusform>%n documentos</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>Substituído %1 em %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>Substituída %n ocorrência</numerusform>
            <numerusform>Substituídas %n ocorrências</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>Impossível processar documento não salvo</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>Documento principal %1 não pode ser lido</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 não está configurado corretamente</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>Impossível executar %1</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>O programa &quot;%1&quot; não foi encontrado.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Procurado nas pastas:</translation>
    </message>
    <message>
        <source>Check configuration of the %1 tool and path settings in the Preferences dialog.</source>
        <translation>Verifique a configuração da ferramenta %1 e as definições de caminho na caixa de Preferências.</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>Processo interrompido pelo usuário</translation>
    </message>
    <message>
        <source>Hide Output Panel</source>
        <translation>Esconder Painel de Informações</translation>
    </message>
    <message>
        <source>Show Output Panel</source>
        <translation>Exibir Painel de Informações</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Compilar com &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>Comando &quot;%1&quot; não definido</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Nenhum arquivo encontrado</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>Nenhum arquivo auxiliar associado a esse documento atualmente.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>novo.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Ortografia</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Inverter Caixa</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Exibir</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Modo de auto-indentação</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Realce de sintaxe</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Aspas Automáticas</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Barra de ferramentas de composição</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Barra de ferramentas de Edição</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Salvar Como...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Reverter à versão salva</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Procurar...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Procurar Outra Vez</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Substituir...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Copiar para Procurar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Copiar para Substituir</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Ir para a Linha...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Encontrar Seleção</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecionar Tudo</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Fonte...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Indentar</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Remover indentação</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentar</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Descomentar</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>Quebrar linhas</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Sobre TeXworks...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Empilhar</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Distribuir</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferências...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Ir para a Previsão</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Novo a partir de Modelo...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Exibir Seleção</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>MAIÚSCULAS FIXAS</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>minúsculas fixas</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Equilibrar delimitadores</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Visitar a página do TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escrever para a lista de usuários</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Lado a Lado</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Colocar à esquerda</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Colocar à Direita</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Substituir Outra Vez</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Remover Arquivos Auxiliares...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Sair do TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Inverter Caixa</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>Quebra de linha...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Números de linha</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation type="unfinished">Impossível ler arquivo &quot;%1&quot;:
%2. {1&quot;?} {2?}</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation type="unfinished">Impossível gravar arquivo &quot;%1&quot;:
%2. {1&quot;?} {2?}</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>padrão</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Novo Arquivo usando Modelo</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Escolha um modelo para o novo documento:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>Novo Argumento</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Configuração da Ferramenta</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumentos:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Exibir PDF depois de executar</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
